
# Slot: emit_prefixes


a list of Curie prefixes that are used in the representation of instances of the model.  All prefixes in this list are added to the prefix sections of the target models.

URI: [linkml:emit_prefixes](https://w3id.org/linkml/emit_prefixes)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) &#8594;  <sub>0..\*</sub> [Ncname](Ncname.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
